@@ -55,6 +55,13 @@ func (s *sectionedTemplate) substituteEnvVars() {
 		lineContents := expandedTemplateLine.LineContents
 		noCommentsLineContents, _, _ := strings.Cut(expandedTemplateLine.LineContents, "#")
 
+		foundEnvVarValues := []struct {
+			value              string
+			envVarWithBrackets string
+		}{}
+
+		prevNumFatals := len(s.fatals)
+
 		for _, envVarWithBrackets := range envVarExpressionRe.FindAllString(noCommentsLineContents, -1) {
 			envVarKeyStr := envVarKeyRe.FindStringSubmatch(envVarWithBrackets)
 			if len(envVarKeyStr) != 2 {
@@ -83,25 +90,50 @@ func (s *sectionedTemplate) substituteEnvVars() {
 				continue
 			}
 
-			expandedLines := strings.Replace(lineContents, envVarWithBrackets, value, 1)
-			splitExpandedLines := strings.Split(strings.ReplaceAll(expandedLines, "\r\n", "\n"), "\n")
-
-			for _, splitExpandedLine := range splitExpandedLines {
-				localExpandedTemplateLines = append(localExpandedTemplateLines, expandedSourceMarker{
-					sourceMarker: sourceMarker{
-						LineContents:    splitExpandedLine,
-						SourceLineIndex: expandedTemplateLine.SourceLineIndex,
-					},
-					expanded: true,
-				})
-			}
+			foundEnvVarValues = append(foundEnvVarValues, struct {
+				value              string
+				envVarWithBrackets string
+			}{value, envVarWithBrackets})
 		}
 
-		if len(localExpandedTemplateLines) == 0 {
+		if len(foundEnvVarValues) == 0 {
 			newExpandedTemplateLines = append(newExpandedTemplateLines, expandedTemplateLine)
-		} else {
-			newExpandedTemplateLines = append(newExpandedTemplateLines, localExpandedTemplateLines...)
+			continue
 		}
+
+		if prevNumFatals < len(s.fatals) {
+			// When the fatal is set it reads from the expanded source
+			// lines as it happens. The stuff below will never be read.
+			continue
+		}
+
+		var expandedResult string
+		tempLineContents := lineContents
+
+		for _, foundValue := range foundEnvVarValues {
+			foundIndex := strings.Index(tempLineContents, foundValue.envVarWithBrackets)
+
+			expandedResult += tempLineContents[:foundIndex]
+			expandedResult += foundValue.value
+
+			tempLineContents = tempLineContents[foundIndex+len(foundValue.envVarWithBrackets):]
+		}
+
+		expandedResult += tempLineContents
+
+		splitExpandedLines := strings.Split(strings.ReplaceAll(expandedResult, "\r\n", "\n"), "\n")
+
+		for _, splitExpandedLine := range splitExpandedLines {
+			localExpandedTemplateLines = append(localExpandedTemplateLines, expandedSourceMarker{
+				sourceMarker: sourceMarker{
+					LineContents:    splitExpandedLine,
+					SourceLineIndex: expandedTemplateLine.SourceLineIndex,
+				},
+				expanded: true,
+			})
+		}
+
+		newExpandedTemplateLines = append(newExpandedTemplateLines, localExpandedTemplateLines...)
 	}
 
 	s.expandedTemplateLines = newExpandedTemplateLines
